@@ -36,8 +36,8 @@
 #ifndef META_MODELICA_DATA_H_
 #define META_MODELICA_DATA_H_
 
-#include "util/omc_init.h"
-#include "util/base_array.h"
+#include "../util/omc_init.h"
+#include "../util/base_array.h"
 
 /*
  *
@@ -63,7 +63,7 @@
  * - 2^(32-10) + 1 (header) on 32 bit systems
  * - 2^(64-10) + 1 (header) on 64 bit systems
  */
-#if defined(_LP64) || defined(_LLP64) || defined(_WIN64)
+#if defined(_LP64) || defined(_LLP64) || defined(_WIN64) || defined(__MINGW64__)
 #define MMC_MAX_SLOTS (18014398509481984) /* max words slots header */
 #else
 #define MMC_MAX_SLOTS (4194304)           /* max words slots header */
@@ -72,38 +72,6 @@
 /* max object size on 32/64 bit systems in bytes */
 #define MMC_MAX_OBJECT_SIZE_BYTES MMC_WORDS_TO_BYTES(MMC_MAX_SLOTS)
 
-#if defined(_LP64)
-#define MMC_SIZE_DBL 8
-#define MMC_SIZE_INT 8
-#define MMC_LOG2_SIZE_INT 3
-#define PRINT_MMC_SINT_T "ld"
-#define PRINT_MMC_UINT_T "lu"
-typedef unsigned long mmc_uint_t;
-typedef long mmc_sint_t;
-#elif defined(_LLP64) || defined(_WIN64) || defined(__MINGW64__)
-#define MMC_SIZE_DBL 8
-#define MMC_SIZE_INT 8
-#define MMC_LOG2_SIZE_INT 3
-#ifndef PRIu64
-#define PRIu64 "I64u"
-#endif
-#ifndef PRId64
-#define PRId64 "I64d"
-#endif
-#define PRINT_MMC_SINT_T PRId64
-#define PRINT_MMC_UINT_T PRIu64
-typedef unsigned long long mmc_uint_t;
-typedef long long mmc_sint_t;
-#else
-#define MMC_SIZE_DBL 8
-#define MMC_SIZE_INT 4
-#define MMC_LOG2_SIZE_INT 2
-#define PRINT_MMC_SINT_T "ld"
-#define PRINT_MMC_UINT_T "lu"
-typedef unsigned int mmc_uint_t;
-typedef int mmc_sint_t;
-#endif
-
 /* adrpo: circumvent MinGW GCC 4.4.0 bugs with optimization */
 #if defined(__MINGW32__)
 #define GCC_VERSION (__GNUC__ * 10000 \
@@ -137,17 +105,17 @@ typedef int mmc_switch_type;
 /* RML-style tagged pointers */
 #define MMC_TAGPTR(p)             ((void*)((char*)(p) + 3))
 #define MMC_UNTAGPTR(x)           ((void*)((char*)(x) - 3))
-#define MMC_IS_INTEGER(X)         (0 == ((mmc_sint_t) X & 1))
-#define MMC_TAGFIXNUM(i)          (((i) << 1)+0)
+#define MMC_IS_INTEGER(X)         (0 == ((mmc_sint_t) (X) & 1))
+#define MMC_TAGFIXNUM(i)          ((((mmc_uint_t) (i)) << 1)+0)
 #define MMC_UNTAGFIXNUM(X)        (((mmc_sint_t) (X)) >> 1)
 
 #else
 
 #define MMC_TAGPTR(p)             ((void*)((char*)(p) + 0))
 #define MMC_UNTAGPTR(x)           ((void*)((char*)(x) - 0))
-#define MMC_IS_INTEGER(X)         (1 == ((mmc_sint_t) X & 1))
-#define MMC_TAGFIXNUM(i)          (((i) << 1)+1)
-#define MMC_UNTAGFIXNUM(X)        (((mmc_sint_t) (X-1)) >> 1)
+#define MMC_IS_INTEGER(X)         (1 == ((mmc_sint_t) (X) & 1))
+#define MMC_TAGFIXNUM(i)          ((((mmc_uint_t) (i)) << 1)+1)
+#define MMC_UNTAGFIXNUM(X)        (((mmc_sint_t) ((X)-1)) >> 1)
 
 #endif
 
@@ -175,7 +143,7 @@ typedef int mmc_switch_type;
 #define MMC_HDRISSTRING(hdr)      (((hdr) & (7)) == 5)
 #define MMC_HDRSTRLEN(hdr)        (((hdr) >> (3)) - MMC_SIZE_INT)
 #define MMC_STRINGDATA(x)         (((struct mmc_string*)MMC_UNTAGPTR(x))->data)
-#define MMC_HDRSTRINGSLOTS(hdr)   (hdr >> (3+MMC_LOG2_SIZE_INT))
+#define MMC_HDRSTRINGSLOTS(hdr)   ((hdr) >> (3+MMC_LOG2_SIZE_INT))
 
 #define MMC_HDRSLOTS(hdr)         ((MMC_HDRISSTRING(hdr)) ? (MMC_HDRSTRINGSLOTS(hdr)) : ((hdr) >> 10))
 #define MMC_HDRCTOR(hdr)          (((hdr) >> 2) & 255)
@@ -215,7 +183,7 @@ typedef int mmc_switch_type;
 #define MMC_DEFSTRINGLIT(NAME,LEN,VAL)  \
     struct {        \
       mmc_uint_t header;    \
-      const char data[LEN+1];    \
+      const char data[(LEN)+1];    \
     } NAME = { MMC_STRINGHDR(LEN), VAL }
 #define MMC_REFSTRINGLIT(NAME) MMC_TAGPTR(&(NAME).header)
 
@@ -229,7 +197,6 @@ typedef int mmc_switch_type;
 #define mmc_mk_integer mmc_mk_icon
 #define mmc_mk_boolean mmc_mk_bcon
 #define mmc_mk_real mmc_mk_rcon
-void* mmc_mk_modelica_array(base_array_t);
 
 void mmc_catch_dummy_fn();
 
@@ -243,15 +210,22 @@ void mmc_catch_dummy_fn();
 #define MMC_CATCH_INTERNAL(X) } threadData->X = old_jumper;}
 #endif
 #define MMC_CATCH() MMC_CATCH_INTERNAL(mmc_jumper)}
+#define MMC_RESTORE_INTERNAL(X) threadData->X = old_jumper;
 
 #define MMC_THROW_INTERNAL() {longjmp(*threadData->mmc_jumper,1);}
 #define MMC_THROW() {longjmp(*((threadData_t*)pthread_getspecific(mmc_thread_data_key))->mmc_jumper,1);}
 #define MMC_ELSE() } else { threadData->mmc_jumper = old_jumper;
 
-#define MMC_TRY_TOP() { threadData_t threadDataOnStack = {0}, *oldThreadData = (threadData_t*)pthread_getspecific(mmc_thread_data_key),*threadData = &threadDataOnStack; pthread_setspecific(mmc_thread_data_key,threadData); pthread_mutex_init(&threadData->parentMutex,NULL); mmc_init_stackoverflow(threadData); MMC_TRY_INTERNAL(mmc_jumper) threadData->mmc_stack_overflow_jumper = threadData->mmc_jumper; /* Let the default stack overflow handler be the top-level handler */
-#define MMC_TRY_TOP_INTERNAL() { threadData_t *oldThreadData = (threadData_t*)pthread_getspecific(mmc_thread_data_key); pthread_setspecific(mmc_thread_data_key,threadData); pthread_mutex_init(&threadData->parentMutex,NULL); mmc_init_stackoverflow(threadData); MMC_TRY_INTERNAL(mmc_jumper) threadData->mmc_stack_overflow_jumper = threadData->mmc_jumper;
+#define MMC_TRY_TOP() { threadData_t threadDataOnStack = {0}, *oldThreadData = (threadData_t*)pthread_getspecific(mmc_thread_data_key),*threadData = &threadDataOnStack; pthread_setspecific(mmc_thread_data_key,threadData); pthread_mutex_init(&threadData->parentMutex,NULL); mmc_init_stackoverflow_fast(threadData, oldThreadData); MMC_TRY_INTERNAL(mmc_jumper) threadData->mmc_stack_overflow_jumper = threadData->mmc_jumper; /* Let the default stack overflow handler be the top-level handler */
+
+#define MMC_TRY_TOP_SET(X) { threadData_t threadDataOnStack = *((threadData_t*)X), *oldThreadData = (threadData_t*)pthread_getspecific(mmc_thread_data_key),*threadData = &threadDataOnStack; pthread_setspecific(mmc_thread_data_key,threadData); pthread_mutex_init(&threadData->parentMutex,NULL); mmc_init_stackoverflow_fast(threadData, oldThreadData); MMC_TRY_INTERNAL(mmc_jumper) threadData->mmc_stack_overflow_jumper = threadData->mmc_jumper; /* Let the default stack overflow handler be the top-level handler */
+
+#define MMC_TRY_TOP_INTERNAL() { threadData_t *oldThreadData = (threadData_t*)pthread_getspecific(mmc_thread_data_key); pthread_setspecific(mmc_thread_data_key,threadData); pthread_mutex_init(&threadData->parentMutex,NULL); mmc_init_stackoverflow_fast(threadData, oldThreadData); MMC_TRY_INTERNAL(mmc_jumper) threadData->mmc_stack_overflow_jumper = threadData->mmc_jumper;
 #define MMC_CATCH_TOP(X) pthread_setspecific(mmc_thread_data_key,oldThreadData); } else {pthread_setspecific(mmc_thread_data_key,oldThreadData);X;}}}
 
+/* use this to allocate and initialize threadData */
+#define MMC_ALLOC_AND_INIT_THREADDATA(_omc_threadData) { size_t len = sizeof(threadData_t); _omc_threadData = (threadData_t*)GC_malloc_uncollectable(len); memset(_omc_threadData, 0, len); pthread_setspecific(mmc_thread_data_key, _omc_threadData); pthread_mutex_init(&_omc_threadData->parentMutex,NULL); mmc_init_stackoverflow(_omc_threadData); }
+
 /* adrpo: assume MMC_DBL_PAD always! */
 struct mmc_real_lit { /* there must be no padding between `header' and `data' */
     mmc_uint_t filler;
