@@ -100,14 +100,13 @@ static void nlsKinsolConfigSetup(NLS_KINSOL_DATA *kinsolData) {
 }
 
 /**
- * @brief (Re-) Initialize KINSOL data.
+ * @brief Initialize KINSOL data.
  *
- * Initialize KINSOL data. If the KINSOL memory block was already initialized
- * free it first and then reinitialize.
+ * Allocate memory for KINSOL data and Jacobian.
  *
  * @param kinsolData          KINSOL data.
  */
-void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
+void initKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
   int flag;
   int printLevel;
   int size = kinsolData->size;
@@ -115,27 +114,29 @@ void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
   SPARSE_PATTERN* sparsePattern = nlsData->sparsePattern;
 
   /* Free KINSOL memory block */
-  if (kinsolData->kinsolMemory) {
-    KINFree((void *)&kinsolData->kinsolMemory);
+  if (kinsolData->kinsolMemory != NULL || kinsolData->J != NULL || kinsolData->scaledJ != NULL) {
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
+                     "KINSOL: Already allocated kinsol memory. Loosing memory!");
   }
 
   /* Create KINSOL memory block */
   kinsolData->kinsolMemory = KINCreate();
   if (kinsolData->kinsolMemory == NULL) {
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: In function KINCreate: An error occurred.");
   }
 
   /* Set error handler and print level */
   if (!nlsData->logActive) {
     printLevel = 0;
-  } else if (ACTIVE_STREAM(LOG_NLS_V)) {
+  } else if (OMC_ACTIVE_STREAM(OMC_LOG_NLS_V)) {
     printLevel = 3;
-  } else if (ACTIVE_STREAM(LOG_NLS)) {
+  } else if (OMC_ACTIVE_STREAM(OMC_LOG_NLS)) {
     printLevel = 1;
   } else {
     printLevel = 0;
   }
+  infoStreamPrint(OMC_LOG_NLS, 0, "KINSOL: log level %i", printLevel);
   flag = KINSetPrintLevel(kinsolData->kinsolMemory, printLevel);
   checkReturnFlag_SUNDIALS(flag, SUNDIALS_KIN_FLAG, "KINSetPrintLevel");
 
@@ -164,8 +165,7 @@ void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
       kinsolData->nnz = sparsePattern->numberOfNonZeros;
     }
     kinsolData->J = SUNSparseMatrix(size, size, kinsolData->nnz, CSC_MAT);
-  } else {
-    kinsolData->J = NULL;
+    kinsolData->scaledJ = SUNSparseMatrix(size, size, kinsolData->nnz, CSC_MAT);
   }
 
   /* Create linear solver object */
@@ -189,7 +189,7 @@ void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
     throwStreamPrint(NULL, "KINSOL: Unknown linear solver method.");
   }
   /* Log used solver */
-  infoStreamPrint(LOG_NLS, 0, "KINSOL: Using linear solver method %s", NLS_LS_METHOD[kinsolData->linearSolverMethod]);
+  infoStreamPrint(OMC_LOG_NLS, 0, "KINSOL: Using linear solver method %s", NLS_LS_METHOD[kinsolData->linearSolverMethod]);
 
   /* Set linear solver */
   flag = KINSetLinearSolver(kinsolData->kinsolMemory, kinsolData->linSol,
@@ -203,7 +203,7 @@ void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
     } else if (sparsePattern != NULL) {
       flag = KINSetJacFn(kinsolData->kinsolMemory, nlsSparseJac); /* Use numeric Jacobian with sparsity pattern */
     } else {
-      throwStreamPrint(NULL, "KINSOL: In function resetKinsolMemory: Sparse linear solver KLU needs sparse Jacobian, but no sparsity pattern is available. Use a dense non-linear solver instead of KINSOL.");
+      throwStreamPrint(NULL, "KINSOL: In function initKinsolMemory: Sparse linear solver KLU needs sparse Jacobian, but no sparsity pattern is available. Use a dense non-linear solver instead of KINSOL.");
     }
     checkReturnFlag_SUNDIALS(flag, SUNDIALS_KINLS_FLAG, "KINSetJacFn");
   }
@@ -218,9 +218,10 @@ void resetKinsolMemory(NLS_KINSOL_DATA *kinsolData) {
  * @param size                  Size of non-linear problem.
  * @param userData              Pointer to set NLS user data.
  * @param attemptRetry          True if KINSOL should retry with different settings after solution failed.
+ * @param isPatternAvailable    True if sparsity pattern of Jacobian is available. Allocate work vectors for KLU in that case.
  * @return NLS_KINSOL_DATA*     Pointer to allocated KINSOL data.
  */
-NLS_KINSOL_DATA* nlsKinsolAllocate(int size, NLS_USERDATA* userData, modelica_boolean attemptRetry) {
+NLS_KINSOL_DATA* nlsKinsolAllocate(int size, NLS_USERDATA* userData, modelica_boolean attemptRetry, modelica_boolean isPatternAvailable) {
   /* Allocate system data */
   NLS_KINSOL_DATA *kinsolData = (NLS_KINSOL_DATA *)calloc(1, sizeof(NLS_KINSOL_DATA));
 
@@ -242,11 +243,26 @@ NLS_KINSOL_DATA* nlsKinsolAllocate(int size, NLS_USERDATA* userData, modelica_bo
   kinsolData->fTmp = N_VNew_Serial(size);
 
   kinsolData->y = N_VNew_Serial(size);
+  kinsolData->J = NULL;
+
+  /* tmp1, tmp2 only needed for numeric Jacobian */
+  if (userData->nlsData->analyticalJacobianColumn != NULL &&
+      isPatternAvailable &&
+      kinsolData->linearSolverMethod == NLS_LS_KLU)
+  {
+    kinsolData->tmp1 = NULL;
+    kinsolData->tmp2 = NULL;
+  } else {
+    kinsolData->tmp1 = N_VNew_Serial(size);
+    kinsolData->tmp2 = N_VNew_Serial(size);
+  }
+  /* Scaled Jacobian is allocated with J */
+  kinsolData->scaledJ = NULL;
 
   kinsolData->kinsolMemory = NULL;
   kinsolData->userData = userData;
 
-  resetKinsolMemory(kinsolData);
+  initKinsolMemory(kinsolData);
 
   return kinsolData;
 }
@@ -271,6 +287,10 @@ void nlsKinsolFree(NLS_KINSOL_DATA* kinsolData) {
   SUNLinSolFree(kinsolData->linSol);
   SUNMatDestroy(kinsolData->J);
   N_VDestroy_Serial(kinsolData->y);
+  if (kinsolData->tmp1 != NULL) {
+    N_VDestroy_Serial(kinsolData->tmp1);
+    N_VDestroy_Serial(kinsolData->tmp2);
+  }
 
   freeNlsUserData(kinsolData->userData);
   free(kinsolData);
@@ -322,11 +342,11 @@ static int nlsKinsolResiduals(N_Vector x, N_Vector f, void* userData) {
  * @param N               Size of vecX and vecFX.
  * @param vecX            Vector x.
  * @param vecFX           Residual vector f(x).
- * @param Jac             Jacobian matrix J(x).
+ * @param Jac             Dense Jacobian matrix J(x).
  * @param kinsolUserData  Pointer to Kinsol user data.
- * @param tmp1            Work vector.
- * @param tmp2            Work vector.
- * @return int            Return 0 on success.
+ * @param tmp1            Unused, only to match interface of KINLsJacFn
+ * @param tmp2            Unused, only to match interface of KINLsJacFn
+ * @return int            Return 0 on success, -1 on failure.
  */
 static int nlsDenseJac(long int N,
                        N_Vector vecX,
@@ -340,6 +360,12 @@ static int nlsDenseJac(long int N,
   NONLINEAR_SYSTEM_DATA *nlsData = kinsolUserData->nlsData;
   NLS_KINSOL_DATA *kinsolData = (NLS_KINSOL_DATA *)nlsData->solverData;
 
+  if (SUNMatGetID(Jac) != SUNMATRIX_DENSE) {
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
+                     "KINSOL: nlsDenseJac illegal input Jac. Matrix is not dense!");
+    return -1;
+  }
+
   /* prepare variables */
   double *x = N_VGetArrayPointer(vecX);
   double *fx = N_VGetArrayPointer(vecFX);
@@ -381,11 +407,11 @@ static int nlsDenseJac(long int N,
   }
 
   /* debug */
-  if (ACTIVE_STREAM(LOG_NLS_JAC)) {
-    infoStreamPrint(LOG_NLS_JAC, 1, "KINSOL: Dense matrix.");
-    SUNDenseMatrix_Print(Jac, stdout); /* TODO: Print in LOG_NLS_JAC */
+  if (OMC_ACTIVE_STREAM(OMC_LOG_NLS_JAC)) {
+    infoStreamPrint(OMC_LOG_NLS_JAC, 1, "KINSOL: Dense matrix.");
+    SUNDenseMatrix_Print(Jac, stdout); /* TODO: Print in OMC_LOG_NLS_JAC */
     nlsKinsolJacSumDense(Jac);
-    messageClose(LOG_NLS_JAC);
+    messageClose(OMC_LOG_NLS_JAC);
   }
 
   /* performance measurement and statistics */
@@ -408,7 +434,7 @@ static void finishSparseColPtr(SUNMatrix A, int nnz) {
 
   /* TODO: Remove this check for performance reasons? */
   if (SM_SPARSETYPE_S(A) != CSC_MAT) {
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: In function finishSparseColPtr: Wrong sparse format of SUNMatrix A.");
   }
 
@@ -418,8 +444,8 @@ static void finishSparseColPtr(SUNMatrix A, int nnz) {
   /* Check for empty rows */
   for (i = 1; i < SM_COLUMNS_S(A) + 1; ++i) {
     if (SM_INDEXPTRS_S(A)[i] == SM_INDEXPTRS_S(A)[i - 1]) {
-      warningStreamPrint(LOG_STDOUT, 0,
-                         "KINSOL: Jacobian row %d singular. See LOG_NLS for "
+      warningStreamPrint(OMC_LOG_STDOUT, 0,
+                         "KINSOL: Jacobian row %d singular. See OMC_LOG_NLS for "
                          "more information.",
                          i);
       SM_INDEXPTRS_S(A)[i] = SM_INDEXPTRS_S(A)[i - 1];
@@ -451,6 +477,12 @@ static int nlsSparseJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
   NLS_KINSOL_DATA *kinsolData;
   SPARSE_PATTERN *sparsePattern;
 
+  if (SUNMatGetID(Jac) != SUNMATRIX_SPARSE || SM_SPARSETYPE_S(Jac) == CSR_MAT) {
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
+                     "KINSOL: nlsSparseJac illegal input Jac. Matrix is not sparse!");
+    return -1;
+  }
+
   double *x;
   double *fx;
   double *xsave;
@@ -526,14 +558,14 @@ static int nlsSparseJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
   finishSparseColPtr(Jac, sparsePattern->numberOfNonZeros);
 
   /* Debug print */
-  if (ACTIVE_STREAM(LOG_NLS_JAC)) {
-    infoStreamPrint(LOG_NLS_JAC, 1, "KINSOL: Sparse Matrix.");
+  if (OMC_ACTIVE_STREAM(OMC_LOG_NLS_JAC)) {
+    infoStreamPrint(OMC_LOG_NLS_JAC, 1, "KINSOL: Sparse Matrix.");
     SUNSparseMatrix_Print(Jac, stdout);
     nlsKinsolJacSumSparse(Jac);
-    messageClose(LOG_NLS_JAC);
+    messageClose(OMC_LOG_NLS_JAC);
   }
-  if (ACTIVE_STREAM(LOG_DEBUG)) {
-    sundialsPrintSparseMatrix(Jac, "A", LOG_JAC);
+  if (OMC_ACTIVE_STREAM(OMC_LOG_DEBUG)) {
+    sundialsPrintSparseMatrix(Jac, "A", OMC_LOG_JAC);
   }
 
   /* performance measurement and statistics */
@@ -548,10 +580,10 @@ static int nlsSparseJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
  *
  * @param vecX
  * @param vecFX     just for interface compatibility, will not be used here
- * @param Jac
- * @param userData
- * @param tmp1
- * @param tmp2
+ * @param Jac       Allocated Jacobian, contains symbolic Jacobian on exit
+ * @param userData  Void pointer to user data of type NLS_USERDATA*.
+ * @param tmp1      Unused, only to match interface of KINLsJacFn
+ * @param tmp2      Unused, only to match interface of KINLsJacFn
  * @return int
  */
 int nlsSparseSymJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
@@ -572,6 +604,12 @@ int nlsSparseSymJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
   long int i, j, ii;
   int nth;
 
+  if (SUNMatGetID(Jac) != SUNMATRIX_SPARSE || SM_SPARSETYPE_S(Jac) == CSR_MAT) {
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
+                     "KINSOL: nlsSparseJac illegal input Jac. Matrix is not sparse!");
+    return -1;
+  }
+
   /* Access userData and nonlinear system data */
   kinsolUserData = (NLS_USERDATA *)userData;
   data = kinsolUserData->data;
@@ -607,7 +645,7 @@ int nlsSparseSymJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
       }
     }
     /* Evaluate Jacobian column */
-    ((nlsData->analyticalJacobianColumn))(data, threadData, analyticJacobian, NULL);
+    nlsData->analyticalJacobianColumn(data, threadData, analyticJacobian, NULL);
 
     /* Save column in Jac and unset seed variables */
     for (ii = 0; ii < kinsolData->size; ii++) {
@@ -631,11 +669,11 @@ int nlsSparseSymJac(N_Vector vecX, N_Vector vecFX, SUNMatrix Jac,
   finishSparseColPtr(Jac, sparsePattern->numberOfNonZeros);
 
   /* Debug print */
-  if (ACTIVE_STREAM(LOG_NLS_JAC)) {
-    infoStreamPrint(LOG_NLS_JAC, 1, "KINSOL: Sparse Matrix.");
-    SUNSparseMatrix_Print(Jac, stdout); /* TODO: Print in LOG_NLS_JAC */
+  if (OMC_ACTIVE_STREAM(OMC_LOG_NLS_JAC)) {
+    infoStreamPrint(OMC_LOG_NLS_JAC, 1, "KINSOL: Sparse Matrix.");
+    SUNSparseMatrix_Print(Jac, stdout); /* TODO: Print in OMC_LOG_NLS_JAC */
     nlsKinsolJacSumSparse(Jac);
-    messageClose(LOG_NLS_JAC);
+    messageClose(OMC_LOG_NLS_JAC);
   }
 
   /* performance measurement and statistics */
@@ -665,11 +703,11 @@ static void nlsKinsolJacSumDense(SUNMatrix A) {
     }
 
     if (sum == 0.0) { /* TODO: Don't check for equality(!), maybe use DBL_EPSILON */
-      warningStreamPrint(LOG_NLS_V, 0,
+      warningStreamPrint(OMC_LOG_NLS_V, 0,
                          "KINSOL: Column %d of Jacobian is zero. Jacobian is singular.",
                          i);
     } else {
-      infoStreamPrint(LOG_NLS_JAC, 0, "Column %d of Jacobian absolute sum = %g",
+      infoStreamPrint(OMC_LOG_NLS_JAC, 0, "Column %d of Jacobian absolute sum = %g",
                       i, sum);
     }
   }
@@ -690,7 +728,7 @@ static void nlsKinsolJacSumSparse(SUNMatrix A) {
 
   /* Check format of A */
   if (SM_SPARSETYPE_S(A) != CSC_MAT) {
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: In function nlsKinsolJacSumSparse: Wrong sparse format "
                      "of SUNMatrix A.");
   }
@@ -703,11 +741,11 @@ static void nlsKinsolJacSumSparse(SUNMatrix A) {
     }
 
     if (sum == 0.0) { /* TODO: Don't check for equality(!), maybe use DBL_EPSILON */
-      warningStreamPrint(LOG_NLS_V, 0,
+      warningStreamPrint(OMC_LOG_NLS_V, 0,
                          "KINSOL: Column %d of Jacobian is zero. Jacobian is singular.",
                          i);
     } else {
-      infoStreamPrint(LOG_NLS_JAC, 0, "Column %d of Jacobian absolute sum = %g",
+      infoStreamPrint(OMC_LOG_NLS_JAC, 0, "Column %d of Jacobian absolute sum = %g",
                       i, sum);
     }
   }
@@ -766,7 +804,7 @@ static void nlsKinsolResetInitial(DATA *data, NLS_KINSOL_DATA *kinsolData,
     memcpy(xStart, nlsData->nlsxOld, nlsData->size * (sizeof(double)));
     break;
   default:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: Function nlsKinsolResetInitial: Unknown mode %d.",
                      (int)mode);
   }
@@ -810,10 +848,10 @@ static void nlsKinsolXScaling(DATA *data, NLS_KINSOL_DATA *kinsolData,
     }
     break;
   case SCALING_JACOBIAN:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: Function nlsKinsolXScaling: Invalid mode SCALING_JACOBIAN.");
   default:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: Function nlsKinsolXScaling: Unknown mode %d.", (int)mode);
   }
 }
@@ -831,11 +869,9 @@ static void nlsKinsolFScaling(DATA *data, NLS_KINSOL_DATA *kinsolData,
                               scalingMode mode) {
   double *fScaling = NV_DATA_S(kinsolData->fScale);
   N_Vector x = kinsolData->initialGuess;
-  SUNMatrix spJac;
-  SUNMatrix denseJac;
-  N_Vector tmp1, tmp2;
 
   int i, j;
+  int ret;
 
   /* If noScaling flag is used overwrite mode */
   if (omc_flag[FLAG_NO_SCALING]) {
@@ -845,43 +881,33 @@ static void nlsKinsolFScaling(DATA *data, NLS_KINSOL_DATA *kinsolData,
   /* Use nominal value or the actual working point for scaling */
   switch (mode) {
   case SCALING_JACOBIAN:
-    tmp1 = N_VNew_Serial(kinsolData->size);
-    tmp2 = N_VNew_Serial(kinsolData->size);
-
     /* Enable scaled jacobian evaluation */
     kinsolData->nominalJac = 1;
 
     /* Calculate the scaled Jacobian */
     if (nlsData->isPatternAvailable && kinsolData->linearSolverMethod == NLS_LS_KLU) {
-      spJac = SUNSparseMatrix(kinsolData->size, kinsolData->size,kinsolData->nnz, CSC_MAT);
       if (kinsolData->solved != NLS_SOLVED) {
         kinsolData->nominalJac = 0;
         if (nlsData->analyticalJacobianColumn != NULL) {
           /* Calculate the sparse Jacobian symbolically  */
-          nlsSparseSymJac(x, kinsolData->fTmp, spJac, kinsolData->userData, tmp1, tmp2);
+          nlsSparseSymJac(x, kinsolData->fTmp, kinsolData->J, kinsolData->userData, NULL, NULL);
         } else {
           /* Update f(x) for the numerical jacobian matrix */
           nlsKinsolResiduals(x, kinsolData->fTmp, kinsolData->userData);
-          nlsSparseJac(x, kinsolData->fTmp, spJac, kinsolData->userData, tmp1, tmp2);
+          nlsSparseJac(x, kinsolData->fTmp, kinsolData->J, kinsolData->userData, kinsolData->tmp1, kinsolData->tmp2);
         }
-        /* Copy the sparse Jacobian into the kinsol data structure for later use */
-        SUNMatCopy_Sparse(spJac, kinsolData->J);
       }
       /* Scale the current Jacobian */
-      spJac = _omc_SUNSparseMatrixVecScaling(kinsolData->J, kinsolData->xScale);
+      SUNMatCopy_Sparse(kinsolData->J, kinsolData->scaledJ);  /* Copy J into scaledJ */
+      ret = _omc_SUNSparseMatrixVecScaling(kinsolData->scaledJ, kinsolData->xScale);
+      if (ret != 0) {
+        errorStreamPrint(OMC_LOG_STDOUT, 0, "KINSOL: _omc_SUNSparseMatrixVecScaling failed.");
+      }
     } else {
       /* Update f(x) for the numerical jacobian matrix */
       nlsKinsolResiduals(x, kinsolData->fTmp, kinsolData->userData);
-      denseJac = SUNDenseMatrix(kinsolData->size, kinsolData->size);
-      nlsDenseJac(nlsData->size, x, kinsolData->fTmp, denseJac,
-                  kinsolData->userData, tmp1, tmp2);
-      spJac = SUNSparseFromDenseMatrix(denseJac, DBL_MIN, CSC_MAT);
-      if (spJac == NULL) {
-        errorStreamPrint(LOG_STDOUT, 0,
-                         "KINSOL: In function SUNSparseFromDenseMatrix: Requirements are "
-                         "violated, or matrix storage request cannot be satisfied.");
-      }
-      SUNMatDestroy(denseJac);
+      nlsDenseJac(nlsData->size, x, kinsolData->fTmp, kinsolData->J,
+                  kinsolData->userData, NULL, NULL);
     }
 
     /* Disable scaled Jacobian evaluation */
@@ -890,18 +916,33 @@ static void nlsKinsolFScaling(DATA *data, NLS_KINSOL_DATA *kinsolData,
     for (i = 0; i < nlsData->size; i++) {
       fScaling[i] = 1e-12;
     }
-    for (i = 0; i < SM_NNZ_S(spJac); ++i) {
-      if (fScaling[SM_INDEXVALS_S(spJac)[i]] < fabs(SM_DATA_S(spJac)[i])) {
-        fScaling[SM_INDEXVALS_S(spJac)[i]] = fabs(SM_DATA_S(spJac)[i]);
+
+    switch (SUNMatGetID(kinsolData->J))
+    {
+    case SUNMATRIX_SPARSE:
+      for (i = 0; i < SM_NNZ_S(kinsolData->scaledJ); ++i) {
+        if (fScaling[SM_INDEXVALS_S(kinsolData->scaledJ)[i]] < fabs(SM_DATA_S(kinsolData->scaledJ)[i])) {
+          fScaling[SM_INDEXVALS_S(kinsolData->scaledJ)[i]] = fabs(SM_DATA_S(kinsolData->scaledJ)[i]);
+        }
       }
+      break;
+    case SUNMATRIX_DENSE:
+      for (i = 0; i < nlsData->size; i++) {
+        for (j = 0; j < nlsData->size; j++) {
+          if (fScaling[i] < fabs(SM_ELEMENT_D(kinsolData->J, j, i))) {
+            fScaling[i] = fabs(SM_ELEMENT_D(kinsolData->J, j, i));
+          }
+        }
+      }
+      break;
+    default:
+      errorStreamPrint(OMC_LOG_STDOUT, 0,
+                       "KINSOL: Function nlsKinsolFScaling: Unknown matrix type.");
     }
+
     /* inverse fScale */
     N_VInv(kinsolData->fScale, kinsolData->fScale);
 
-    /* Free memory */
-    SUNMatDestroy(spJac);
-    N_VDestroy_Serial(tmp1);
-    N_VDestroy_Serial(tmp2);
     break;
   case SCALING_ONES:
     for (i = 0; i < nlsData->size; i++) {
@@ -909,10 +950,10 @@ static void nlsKinsolFScaling(DATA *data, NLS_KINSOL_DATA *kinsolData,
     }
     break;
   case SCALING_NOMINALSTART:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: Function nlsKinsolFScaling: Invalid mode SCALING_NOMINALSTART.");
   default:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: Function nlsKinsolFScaling: Unknown mode %d.", (int)mode);
   }
 }
@@ -933,7 +974,7 @@ static void nlsKinsolConfigPrint(NLS_KINSOL_DATA *kinsolData,
   int eqSystemNumber = nlsData->equationIndex;
   _omc_vector vecStart, vecXScaling, vecFScaling;
 
-  if (!useStream[LOG_NLS_V]) {
+  if (!omc_useStream[OMC_LOG_NLS_V]) {
     return;
   }
 
@@ -944,30 +985,27 @@ static void nlsKinsolConfigPrint(NLS_KINSOL_DATA *kinsolData,
   _omc_initVector(&vecFScaling, kinsolData->size,
                   NV_DATA_S(kinsolData->fScale));
 
-  infoStreamPrint(LOG_NLS_V, 1, "Kinsol Configuration");
   _omc_printVectorWithEquationInfo(
-      &vecStart, "Initial guess values", LOG_NLS_V,
+      &vecStart, "Initial guess values", OMC_LOG_NLS_V,
       modelInfoGetEquation(&data->modelData->modelDataXml, eqSystemNumber));
 
   _omc_printVectorWithEquationInfo(
-      &vecXScaling, "xScaling", LOG_NLS_V,
+      &vecXScaling, "xScaling", OMC_LOG_NLS_V,
       modelInfoGetEquation(&data->modelData->modelDataXml, eqSystemNumber));
 
-  _omc_printVector(&vecFScaling, "fScaling", LOG_NLS_V);
+  _omc_printVector(&vecFScaling, "fScaling", OMC_LOG_NLS_V);
 
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL F tolerance: %g", kinsolData->fnormtol);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL minimal step size %g",
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL F tolerance: %g", kinsolData->fnormtol);
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL minimal step size %g",
                   kinsolData->scsteptol);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL max iterations %d",
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL max iterations %d",
                   20 * kinsolData->size);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL strategy %d",
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL strategy %d",
                   kinsolData->kinsolStrategy);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL current retry %d", kinsolData->retries);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL max step %g", kinsolData->mxnstepin);
-  infoStreamPrint(LOG_NLS_V, 0, "KINSOL linear solver %d",
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL current retry %d", kinsolData->retries);
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL max step %g", kinsolData->mxnstepin);
+  infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL linear solver %d",
                   kinsolData->linearSolverMethod);
-
-  messageClose(LOG_NLS_V);
 }
 
 /**
@@ -993,16 +1031,21 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
 
   switch (errorCode) {
   case KIN_MEM_NULL:
+    throwStreamPrint(NULL, "KINSOL: Memory NULL ERROR %d\n", errorCode);
+    return FALSE;
+    break;
   case KIN_ILL_INPUT:
+    throwStreamPrint(NULL, "KINSOL: Ill input ERROR %d\n", errorCode);
+    return FALSE;
+    break;
   case KIN_NO_MALLOC:
-    errorStreamPrint(LOG_NLS_V, 0,
-                     "KINSOL: Memory issue ERROR %d\n", errorCode);
+    throwStreamPrint(NULL, "KINSOL: Memory issue ERROR %d\n", errorCode);
     return FALSE;
     break;
   /* Just retry with new initial guess */
   case KIN_MXNEWT_5X_EXCEEDED:
     warningStreamPrint(
-        LOG_NLS_V, 0,
+        OMC_LOG_NLS_V, 0,
         "Newton step exceed the maximum step size several times. Try again "
         "after increasing maximum step size.\n");
     kinsolData->maxstepfactor *= 1e5;
@@ -1012,7 +1055,7 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
   /* Just retry without line search */
   case KIN_LINESEARCH_NONCONV:
     warningStreamPrint(
-        LOG_NLS_V, 0,
+        OMC_LOG_NLS_V, 0,
         "kinsols line search did not convergence. Try without.\n");
     kinsolData->kinsolStrategy = KIN_NONE;
     kinsolData->retries--;
@@ -1020,7 +1063,7 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
     break;
   /* Maybe happened because of an out-dated factorization, so just retry */
   case KIN_LSOLVE_FAIL:
-    warningStreamPrint(LOG_NLS_V, 0,
+    warningStreamPrint(OMC_LOG_NLS_V, 0,
                        "KINSOL: Matrix need new factorization. Try again.\n");
     if (kinsolData->linearSolverMethod == NLS_LS_KLU &&
         nlsData->isPatternAvailable) {
@@ -1033,16 +1076,16 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
     break;
   case KIN_MAXITER_REACHED:
   case KIN_REPTD_SYSFUNC_ERR:
-    warningStreamPrint(LOG_NLS_V, 0,
+    warningStreamPrint(OMC_LOG_NLS_V, 0,
                        "KINSOL: Runs into issues retry with different configuration.\n");
     break;
   case KIN_LINIT_FAIL:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "KINSOL: The linear solver's initialization function failed.\n");
     return errorCode;
   case KIN_LSETUP_FAIL:
     /* In case something goes wrong with the symbolic jacobian try the numerical */
-    warningStreamPrint(LOG_NLS_V, 0,
+    warningStreamPrint(OMC_LOG_NLS_V, 0,
                        "KINSOL: The kinls setup routine (lsetup) encountered an error. "
                        "Retry with numerical Jacobian.\n");
     if (kinsolData->linearSolverMethod == NLS_LS_KLU) {
@@ -1053,7 +1096,7 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
           return FALSE;
         }
       } else {
-        errorStreamPrint(LOG_STDOUT, 0, "KINSOL: Trying to switch to numeric Jacobian for sparse solver KLU, but no sparsity pattern is available.");
+        errorStreamPrint(OMC_LOG_STDOUT, 0, "KINSOL: Trying to switch to numeric Jacobian for sparse solver KLU, but no sparsity pattern is available.");
         return FALSE;
       }
     }
@@ -1061,11 +1104,11 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
   case KIN_LINESEARCH_BCFAIL:
     KINGetNumBetaCondFails(kinsolData->kinsolMemory, &outL);
     warningStreamPrint(
-        LOG_NLS_V, 0,
+        OMC_LOG_NLS_V, 0,
         "kinsols runs into issues with beta-condition fails: %ld\n", outL);
     break;
   default:
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "kinsol has a serious solving issue ERROR %d\n",
                      errorCode);
     return FALSE;
@@ -1075,13 +1118,13 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
   /* check if the current solution is sufficient anyway */
   KINGetFuncNorm(kinsolData->kinsolMemory, &fNorm);
   if (fNorm < FTOL_WITH_LESS_ACCURACY) {
-    warningStreamPrint(LOG_NLS_V, 0, "KINSOL: Move forward with a less accurate solution.");
+    warningStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL: Move forward with a less accurate solution.");
     KINSetFuncNormTol(kinsolData->kinsolMemory, FTOL_WITH_LESS_ACCURACY);
     KINSetScaledStepTol(kinsolData->kinsolMemory, FTOL_WITH_LESS_ACCURACY);
     kinsolData->resetTol = TRUE;
     return TRUE;
   } else {
-    warningStreamPrint(LOG_NLS_V, 0, "KINSOL: Current status of fx = %f", fNorm);
+    warningStreamPrint(OMC_LOG_NLS_V, 0, "KINSOL: Current status of fx = %f", fNorm);
   }
 
   /* reconfigure kinsol for another try */
@@ -1137,7 +1180,8 @@ static modelica_boolean nlsKinsolErrorHandler(int errorCode, DATA *data,
 NLS_SOLVER_STATUS nlsKinsolSolve(DATA* data, threadData_t* threadData, NONLINEAR_SYSTEM_DATA* nlsData) {
 
   NLS_KINSOL_DATA *kinsolData = (NLS_KINSOL_DATA *)nlsData->solverData;
-  int indexes[2] = {1, nlsData->equationIndex};
+  int eqSystemNumber = nlsData->equationIndex;
+  int indexes[2] = {1, eqSystemNumber};
 
   int flag;
   long nFEval;
@@ -1147,9 +1191,9 @@ NLS_SOLVER_STATUS nlsKinsolSolve(DATA* data, threadData_t* threadData, NONLINEAR
   double *xStart = NV_DATA_S(kinsolData->initialGuess);
   double fNormValue;
 
-  infoStreamPrintWithEquationIndexes(LOG_NLS_V, omc_dummyFileInfo, 1, indexes,
-                                     "Start Kinsol solver at time %g",
-                                     data->localData[0]->timeValue);
+  infoStreamPrintWithEquationIndexes(OMC_LOG_NLS_V, omc_dummyFileInfo, 1, indexes,
+    "Start solving Non-Linear System %d (size %d) at time %g with Kinsol Solver",
+    eqSystemNumber, (int) nlsData->size, data->localData[0]->timeValue);
 
   /* Solve nonlinear system with KINSol() */
   kinsolData->retries = 0;
@@ -1176,9 +1220,9 @@ NLS_SOLVER_STATUS nlsKinsolSolve(DATA* data, threadData_t* threadData, NONLINEAR
         kinsolData->fScale);        /* scaling vector for function values fval */
 
     if (flag < 0 && kinsolData->attemptRetry) {
-      warningStreamPrint(LOG_NLS, 0, "KINSol finished with errorCode %d.", flag);
+      warningStreamPrint(OMC_LOG_NLS, 0, "KINSol finished with errorCode %d.", flag);
     } else {
-      infoStreamPrint(LOG_NLS_V, 0, "KINSol finished with errorCode %d.", flag);
+      infoStreamPrint(OMC_LOG_NLS_V, 0, "KINSol finished with errorCode %d.", flag);
     }
     /* Try to handle recoverable errors */
     retry = flag < 0 && kinsolData->attemptRetry && nlsKinsolErrorHandler(flag, data, nlsData, kinsolData);
@@ -1195,7 +1239,7 @@ NLS_SOLVER_STATUS nlsKinsolSolve(DATA* data, threadData_t* threadData, NONLINEAR
     nlsData->numberOfIterations += nFEval;
     nlsData->numberOfFEval = kinsolData->countResCalls;
 
-    infoStreamPrint(LOG_NLS_V, 0, "Next try? success = %d, retry = %d, retries = %d = %s\n",
+    infoStreamPrint(OMC_LOG_NLS_V, 0, "Next try? success = %d, retry = %d, retries = %d = %s\n",
                     success, retry, kinsolData->retries,
                     !success && !retry && kinsolData->retries < RETRY_MAX ? "true" : "false");
   } while (!success && retry && kinsolData->retries < RETRY_MAX);
@@ -1220,14 +1264,14 @@ NLS_SOLVER_STATUS nlsKinsolSolve(DATA* data, threadData_t* threadData, NONLINEAR
     memcpy(nlsData->nlsx, xStart, nlsData->size * (sizeof(double)));
   }
 
-  messageClose(LOG_NLS_V);
+  messageClose(OMC_LOG_NLS_V);
 
   return kinsolData->solved;
 }
 
 #else /* WITH_SUNDIALS */
 
-void* nlsKinsolAllocate(int size, void* userData, int attemptRetry) {
+void* nlsKinsolAllocate(int size, void* userData, int attemptRetry, modelica_boolean isPatternAvailable) {
 
   throwStreamPrint(NULL, "No sundials/kinsol support activated.");
   return 0;
