@@ -36,6 +36,7 @@
 #include "TextAnnotation.h"
 #include "Modeling/Commands.h"
 #include "Options/OptionsDialog.h"
+#include "OMPlot.h"
 
 /*!
  * \class TextAnnotation
@@ -251,30 +252,31 @@ void TextAnnotation::parseShapeAnnotation(QString annotation)
 
 void TextAnnotation::parseShapeAnnotation()
 {
-  GraphicItem::parseShapeAnnotation(mpText);
-  FilledShape::parseShapeAnnotation(mpText);
+  GraphicsView *pGraphicsView = getContainingGraphicsView();
+  GraphicItem::parseShapeAnnotation(mpText, pGraphicsView);
+  FilledShape::parseShapeAnnotation(mpText, pGraphicsView);
 
   mExtent = mpText->getExtent();
-  mExtent.evaluate(mpText->getParentModel());
+  mExtent.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   mTextString = mpText->getTextString();
-  mTextString.evaluate(mpText->getParentModel());
+  mTextString.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   mOriginalTextString = mTextString;
   initUpdateTextString();
 
   mFontSize = mpText->getFontSize();
-  mFontSize.evaluate(mpText->getParentModel());
+  mFontSize.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   if (mpText->getTextColor().isValid()) {
     mLineColor = mpText->getTextColor();
-    mLineColor.evaluate(mpText->getParentModel());
+    mLineColor.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   }
   if (!mpText->getFontName().isEmpty()) {
     mFontName = mpText->getFontName();
-    mFontName.evaluate(mpText->getParentModel());
+    mFontName.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   }
   mTextStyles = mpText->getTextStyle();
-  mTextStyles.evaluate(mpText->getParentModel());
+  mTextStyles.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
   mHorizontalAlignment = mpText->getHorizontalAlignment();
-  mHorizontalAlignment.evaluate(mpText->getParentModel());
+  mHorizontalAlignment.evaluate(pGraphicsView->getModelWidget()->getModelInstance());
 }
 
 /*!
@@ -519,6 +521,24 @@ QString TextAnnotation::getShapeAnnotation()
   return QString("Text(").append(annotationString.join(",")).append(")");
 }
 
+/*!
+ * \brief TextAnnotation::getShapeAnnotationJSON
+ * Returns Text annotation in JSON format.
+ * \return
+ */
+QJsonObject TextAnnotation::getShapeAnnotationJSON()
+{
+  QJsonObject jsonObject;
+  jsonObject.insert("extent", mExtent.serialize());
+  jsonObject.insert("textString", mTextString.serialize());
+  jsonObject.insert("fontSize", mFontSize.serialize());
+  jsonObject.insert("textColor", mLineColor.serialize());
+  jsonObject.insert("fontName", mFontName.serialize());
+  jsonObject.insert("textStyle", mTextStyles.serialize());
+  jsonObject.insert("horizontalAlignment", mHorizontalAlignment.serialize());
+  return jsonObject;
+}
+
 void TextAnnotation::updateShape(ShapeAnnotation *pShapeAnnotation)
 {
   // set the default values
@@ -581,16 +601,16 @@ void TextAnnotation::updateTextStringHelper(QRegExp regExp)
           if (!Utilities::isValueLiteralConstant(textValue) || displayUnit.first.isEmpty() || (displayUnit.first.compare("1") == 0 && unit.first.compare("1") == 0)) {
             textValueWithDisplayUnit = textValue;
           } else if (unit.first.compare(displayUnit.first) == 0) {  // Do not do any conversion if unit and displayUnit are same.
-            textValueWithDisplayUnit = QString("%1 %2").arg(textValue, Utilities::convertUnitToSymbol(displayUnit.first));
+            textValueWithDisplayUnit = QString("%1 %2").arg(textValue, OMPlot::Plot::convertUnitToSymbol(displayUnit.first));
           } else {
             OMCProxy *pOMCProxy = MainWindow::instance()->getOMCProxy();
             OMCInterface::convertUnits_res convertUnit = pOMCProxy->convertUnits(unit.first, displayUnit.first);
             if (convertUnit.unitsCompatible) {
               qreal convertedValue = Utilities::convertUnit(textValue.toDouble(), convertUnit.offset, convertUnit.scaleFactor);
               textValue = StringHandler::number(convertedValue);
-              textValueWithDisplayUnit = QString("%1 %2").arg(textValue, Utilities::convertUnitToSymbol(displayUnit.first));
+              textValueWithDisplayUnit = QString("%1 %2").arg(textValue, OMPlot::Plot::convertUnitToSymbol(displayUnit.first));
             } else {
-              textValueWithDisplayUnit = QString("%1 %2").arg(textValue, Utilities::convertUnitToSymbol(unit.first));
+              textValueWithDisplayUnit = QString("%1 %2").arg(textValue, OMPlot::Plot::convertUnitToSymbol(unit.first));
             }
           }
           mTextString.replace(pos, regExp.matchedLength(), textValueWithDisplayUnit);
