@@ -185,6 +185,40 @@ QString ModelicaEditor::wordUnderCursor()
   return mpPlainTextEdit->document()->toPlainText().mid(begin, end - begin);
 }
 
+/*!
+ * \brief ModelicaEditor::symbolAtPosition
+ * Navigate to the Modelica class at position.
+ * \param pos
+ */
+void ModelicaEditor::symbolAtPosition(const QPoint &pos)
+{
+  if (mpModelWidget) {
+    QTextCursor cursor = mpPlainTextEdit->cursorForPosition(pos);
+    cursor.select(QTextCursor::WordUnderCursor);
+
+    int mid = cursor.position();
+    int end = mid;
+
+    while (end < cursor.block().length()) {
+      QChar ch = mpPlainTextEdit->document()->characterAt(end);
+      if (!(ch.isLetterOrNumber() || ch == '.' || ch == '_'))
+        break;
+      end++;
+    }
+
+    int begin = mid - 1;
+    while (begin >= 0) {
+      QChar ch = mpPlainTextEdit->document()->characterAt(begin);
+      if (!(ch.isLetterOrNumber() || ch == '.' || ch == '_'))
+        break;
+      begin--;
+    }
+    begin++;
+
+    mpModelWidget->navigateToClass(mpPlainTextEdit->document()->toPlainText().mid(begin, end - begin));
+  }
+}
+
 /*!
  * \brief Returns the substring from the last occurrence of `word` to the cursor position
  * \param word Starting word of the substring
@@ -224,12 +258,13 @@ void ModelicaEditor::getCompletionSymbols(QString word, QList<CompleterItem> &cl
  */
 LibraryTreeItem *ModelicaEditor::getAnnotationCompletionRoot()
 {
-  LibraryTreeItem *pLibraryRoot = MainWindow::instance()->getLibraryWidget()->getLibraryTreeModel()->getRootLibraryTreeItem();
+  LibraryTreeItem *pLibraryRoot = MainWindow::instance()->getLibraryWidget()->getLibraryTreeModel()->findLibraryTreeItemOneLevel(Helper::OMEditInternal);
   LibraryTreeItem *pModelicaReference = 0;
 
   for (int i = 0; i < pLibraryRoot->childrenSize(); ++i) {
-    if (pLibraryRoot->childAt(i)->getName() == "OpenModelica")
+    if (pLibraryRoot->childAt(i)->getName() == "OpenModelica") {
       pModelicaReference = pLibraryRoot->childAt(i);
+    }
   }
 
   if (pModelicaReference) {
@@ -254,12 +289,11 @@ void ModelicaEditor::getCompletionAnnotations(const QStringList &stack, QList<Co
         QString name = pAnnotation->childAt(i)->getName();
         annotations << CompleterItem(name, name + "(", name, pAnnotation->childAt(i)->getHTMLDescription());
       }
-      QList<ElementInfo *> components = pAnnotation->getComponentsList();
+      QList<ElementInfo> components = pAnnotation->getComponentsList();
       for (int i = 0; i < components.size(); ++i) {
-        QString componentName = components[i]->getName();
-        QString componentValue = components[i]->getParameterValue(MainWindow::instance()->getOMCProxy(), pAnnotation->getNameStructure());
-        annotations << CompleterItem(componentName, QString("%1 = %2").arg(componentName, componentValue), componentName,
-                                     components[i]->getHTMLDescription());
+        QString componentName = components[i].getName();
+        QString componentValue = components[i].getParameterValue(MainWindow::instance()->getOMCProxy(), pAnnotation->getNameStructure());
+        annotations << CompleterItem(componentName, QString("%1 = %2").arg(componentName, componentValue), componentName, components[i].getHTMLDescription());
       }
     }
   }
@@ -511,11 +545,16 @@ void ModelicaEditor::showContextMenu(QPoint point)
 {
   QMenu *pMenu = BaseEditor::createStandardContextMenu();
   pMenu->addSeparator();
+  pMenu->addAction(mpOpenClassAction);
+  pMenu->addSeparator();
   pMenu->addAction(mpToggleCommentSelectionAction);
   pMenu->addSeparator();
   pMenu->addAction(mpFoldAllAction);
   pMenu->addAction(mpUnFoldAllAction);
+  mContextMenuStartPosition = point;
+  mContextMenuStartPositionValid = true;
   pMenu->exec(mapToGlobal(point));
+  mContextMenuStartPositionValid = false;
   delete pMenu;
 }
 
@@ -574,6 +613,8 @@ void ModelicaEditor::contentsHasChanged(int position, int charsRemoved, int char
     /* if user is changing the system library class. */
     if (mpModelWidget->getLibraryTreeItem()->isSystemLibrary() && !mForceSetPlainText) {
       mpInfoBar->showMessage(tr("<b>Warning: </b>You are changing a system library class. System libraries are always read-only. Your changes will not be saved."));
+    } else if (mpModelWidget->isElementMode() && !mForceSetPlainText) {
+      mpInfoBar->showMessage(tr("<b>Warning: </b>Cannot modify the text in the element mode. Your changes will not be saved."));
     } else if (mpModelWidget->getLibraryTreeItem()->isReadOnly() && !mForceSetPlainText) {
       /* if user is changing the read-only class. */
       mpInfoBar->showMessage(tr("<b>Warning: </b>You are changing a read-only class."));
@@ -629,7 +670,7 @@ void ModelicaHighlighter::initializeSettings()
   font.setFamily(mpModelicaEditorPage->getOptionsDialog()->getTextEditorPage()->getFontFamilyComboBox()->currentFont().family());
   font.setPointSizeF(mpModelicaEditorPage->getOptionsDialog()->getTextEditorPage()->getFontSizeSpinBox()->value());
   mpPlainTextEdit->document()->setDefaultFont(font);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
   mpPlainTextEdit->setTabStopDistance((qreal)(mpModelicaEditorPage->getOptionsDialog()->getTextEditorPage()->getTabSizeSpinBox()->value() * QFontMetrics(font).horizontalAdvance(QLatin1Char(' '))));
 #else // QT_VERSION_CHECK
   mpPlainTextEdit->setTabStopWidth(mpModelicaEditorPage->getOptionsDialog()->getTextEditorPage()->getTabSizeSpinBox()->value() * QFontMetrics(font).width(QLatin1Char(' ')));
