@@ -67,6 +67,7 @@ TranslationFlagsWidget::TranslationFlagsWidget(QWidget *pParent)
   mpNLSanalyticJacobianCheckBox = new QCheckBox(tr("Enable analytical jacobian for non-linear strong components"));
   mpParmodautoCheckBox = new QCheckBox(tr("Enable parallelization of independent systems of equations (Experimental)"));
   mpOldInstantiationCheckBox = new QCheckBox(tr("Enable old frontend for code generation"));
+  mpEnableFMUImportCheckBox = new QCheckBox(tr("Enable FMU Import"));
   mpAdditionalTranslationFlagsLabel = new Label(tr("Additional Translation Flags:"));
   mpAdditionalTranslationFlagsLabel->setToolTip(Helper::translationFlagsTip);
   mpAdditionalTranslationFlagsTextBox = new QLineEdit;
@@ -89,6 +90,7 @@ TranslationFlagsWidget::TranslationFlagsWidget(QWidget *pParent)
   pMainLayout->addWidget(mpNLSanalyticJacobianCheckBox, row++, 0, 1, 3);
   pMainLayout->addWidget(mpParmodautoCheckBox, row++, 0, 1, 3);
   pMainLayout->addWidget(mpOldInstantiationCheckBox, row++, 0, 1, 3);
+  pMainLayout->addWidget(mpEnableFMUImportCheckBox, row++, 0, 1, 3);
   pMainLayout->addWidget(mpAdditionalTranslationFlagsLabel, row, 0);
   pMainLayout->addWidget(mpAdditionalTranslationFlagsTextBox, row, 1);
   pMainLayout->addWidget(mpTranslationFlagsHelpButton, row++, 2);
@@ -115,6 +117,7 @@ void TranslationFlagsWidget::applySimulationOptions(const SimulationOptions &sim
   mpNLSanalyticJacobianCheckBox->setChecked(simulationOptions.getNLSanalyticJacobian());
   mpParmodautoCheckBox->setChecked(simulationOptions.getParmodauto());
   mpOldInstantiationCheckBox->setChecked(simulationOptions.getOldInstantiation());
+  mpEnableFMUImportCheckBox->setChecked(simulationOptions.getEnableFMUImport());
   mpAdditionalTranslationFlagsTextBox->setText(simulationOptions.getAdditionalTranslationFlags());
 }
 
@@ -132,6 +135,7 @@ void TranslationFlagsWidget::createSimulationOptions(SimulationOptions *pSimulat
   pSimulationOptions->setNLSanalyticJacobian(mpNLSanalyticJacobianCheckBox->isChecked());
   pSimulationOptions->setParmodauto(mpParmodautoCheckBox->isChecked());
   pSimulationOptions->setOldInstantiation(mpOldInstantiationCheckBox->isChecked());
+  pSimulationOptions->setEnableFMUImport(mpEnableFMUImportCheckBox->isChecked());
   pSimulationOptions->setAdditionalTranslationFlags(mpAdditionalTranslationFlagsTextBox->text());
 }
 
@@ -176,12 +180,16 @@ QString TranslationFlagsWidget::commandLineOptions()
   }
   // parmodauto
   if (mpParmodautoCheckBox->isChecked()) {
-    debugFlags.append("parmodauto");
+    configFlags.append("--parmodauto");
   }
   // enable new instantiation
   if (mpOldInstantiationCheckBox->isChecked()) {
     debugFlags.append("nonewInst");
   }
+  // enable FMU Import
+  if (mpEnableFMUImportCheckBox->isChecked()) {
+    configFlags.append("--allowNonStandardModelica=reinitInAlgorithms");
+  }
 
   QStringList commandLineOptions;
   commandLineOptions.append(configFlags);
