@@ -369,7 +369,7 @@ void TVariablesTreeModel::insertTVariablesItems(QHashIterator<QString, OMVariabl
         tVariableData << variable.name << StringHandler::joinDerivativeAndPreviousVariable(variable.name, tVariable, "der(");
       } else if ((tVariables.size() == count) && (variable.name.startsWith("previous("))) { /* if last item of previous */
         tVariableData << variable.name << StringHandler::joinDerivativeAndPreviousVariable(variable.name, tVariable, "previous(");
-      } else if (tVariables.size() == count && QRegExp("\\[\\d+\\]").exactMatch(tVariable)) { /* if last item of array derivative*/
+      } else if (tVariables.size() == count && QRegularExpression(QRegularExpression::anchoredPattern(Helper::arrayIndexRegularExpression)).match(tVariable).hasMatch()) { /* if last item of array derivative*/
         tVariableData << variable.name << tVariable;
       } else {
         tVariableData << QString("%1%2").arg(parentVarName, tVariable) << tVariable;
@@ -467,7 +467,7 @@ TVariableTreeProxyModel::TVariableTreeProxyModel(QObject *parent)
 
 bool TVariableTreeProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
   if (!filterRegularExpression().pattern().isEmpty()) {
 #else
   if (!filterRegExp().isEmpty()) {
@@ -486,20 +486,20 @@ bool TVariableTreeProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex
       if (pTVariablesTreeItem) {
         QString variableName = pTVariablesTreeItem->getVariableName();
         variableName.remove(QRegularExpression("(\\.mat|\\.plt|\\.csv|_res.mat|_res.plt|_res.csv)"));
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         return variableName.contains(filterRegularExpression());
 #else
         return variableName.contains(filterRegExp());
 #endif
       } else {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         return sourceModel()->data(index).toString().contains(filterRegularExpression());
 #else
         return sourceModel()->data(index).toString().contains(filterRegExp());
 #endif
       }
       QString key = sourceModel()->data(index, filterRole()).toString();
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
       return key.contains(filterRegularExpression());
 #else
       return key.contains(filterRegExp());
@@ -1300,7 +1300,7 @@ void TransformationsWidget::reloadTransformations()
   signalsState = mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(true);
   mpTreeSearchFilters->getCaseSensitiveCheckBox()->setChecked(false);
   mpTreeSearchFilters->getCaseSensitiveCheckBox()->blockSignals(signalsState);
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
   mpTVariableTreeProxyModel->setFilterRegularExpression(QRegularExpression());
 #else
   mpTVariableTreeProxyModel->setFilterRegExp(QRegExp());
@@ -1332,7 +1332,7 @@ void TransformationsWidget::findVariables()
 {
   QString findText = mpTreeSearchFilters->getFilterTextBox()->text();
   Qt::CaseSensitivity caseSensitivity = mpTreeSearchFilters->getCaseSensitiveCheckBox()->isChecked() ? Qt::CaseSensitive: Qt::CaseInsensitive;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
   // TODO: handle PatternSyntax
   QRegularExpression regExp(QRegularExpression::fromWildcard(findText, caseSensitivity, QRegularExpression::UnanchoredWildcardConversion));
   mpTVariableTreeProxyModel->setFilterRegularExpression(regExp);
