@@ -47,11 +47,7 @@
 
 // QT Headers
 #include <QtGlobal>
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QtWidgets>
-#else
-#include <QtGui/QWidget>
-#endif
 
 
 //IAEX Headers
