@@ -868,7 +868,7 @@ namespace IAEX {
     else
     {
       // 2006-01-30 AF, add message box
-      QMessageBox::warning( 0, tr("Warning"), tr("No Output style defined, please define an Output style in stylesheet.xml"), "OK" );
+      QMessageBox::warning(nullptr, tr("Warning"), tr("No Output style defined, please define an Output style in stylesheet.xml"));
     }
 
     QTextCursor cursor = output_->textCursor();
@@ -1498,7 +1498,7 @@ namespace IAEX {
     }
     catch (PlotException &e)
     {
-      QMessageBox::warning( 0, tr("Error"), e.what(), "OK" );
+      QMessageBox::warning(nullptr, tr("Error"), e.what());
     }
   }
 
