@@ -32,11 +32,10 @@
 #ifndef _OMS_FMU_INFO_H_
 #define _OMS_FMU_INFO_H_
 
-#include "Types.h"
+#include "OMSimulator/Types.h"
 
 #include <string>
-#include <fmilib.h>
-
+#include <fmi4c.h>
 namespace oms
 {
   /**
@@ -48,7 +47,7 @@ namespace oms
     FMUInfo(const std::string& path);
     ~FMUInfo();
 
-    void update(fmi_version_enu_t version, fmi2_import_t* fmu);
+    void update(fmiVersion_t version, fmiHandle* fmi4c);
 
     std::string getPath() const {return std::string(path);}
     oms_fmi_kind_enu_t getKind() const {return fmiKind;}
